[![Build Status](https://travis-ci.org/bean3/to-do-list.svg?branch=master)](https://travis-ci.org/bean3/to-do-list)

# Hello, we are potato team!

## Introduce
we develop **potatotodo** (this is todo_list !)  
todo_list's **function** : todo **what?**, set a **category**, Set a **period** and **done?** 

we develop for who can use console  
**but if you can't use console don't worry we prepared --help**

# How to download
first you nead **python(version>=3.6)**

second you have to download pip **(python install pip)**

third you have to download click **(pip install click)**

fourth you have to download colorama **(pip install colorama)**  

finally just download! **(python install potatotodo)**

If you prepare all but you can't download please type this -> **pip3 install potatotodo**  

# How to upgrade  
just typing -> **(pip install —upgrade potatotodo)**  
if do not work, please type -> **(pip uninstall potatotodo)**  

## --help  
* ` potato ` : Show Main Page & Introduction.  
* ` potato --help ` : Show help.    
 You can also use with ` show ` and ` remove ` command, like ` potato show --help `.
* ` potato make ` : Make a new plan. Questions for additional input will appear.    
* ` potato show ` : Print all your plans.  
- > ` potato show --pg [number] ` : Print the page of which you entered.  
- > ` potato show --cat `: Show All categories and print category that only you want to find.  
- > ` potato show --uf ` : Print your unfinished plans.  
- > ` potato show --f ` : Print your finished plans.  
* ` potato remove [index]  `: Remove your plan that index number is [number]. 
- > ` potato remove --all ` : Remove all your plans.
* ` potato modify  [number] ` : Modify your plan that index number is [number].
* ` potato find [text] ` : Find your plan that includes [text].
* ` potato detail [number] ` : Show details of plan that index number is [number].  

### If you need more information please comment here or refer to setup.py !
[LICENSE](https://github.com/bean3/to-do-list/blob/master/LICENSE)

### Developers
[Hyunjun Lee](https://github.com/Alpacadabra/to-do-list) , [Kim Yejun](https://github.com/kyj0701/to-do-list) , [Lee je shin](https://github.com/BeautifulTommorow/to-do-list) , [lee hye jin](https://github.com/bean3/to-do-list) , [Kim tae O](https://github.com/xodh/to-do-list)
